Name:           aseprite
Version:        1.3.9.1
Release:        %mkrel 2
Summary:        Animated sprite editor & pixel art tool
Group:          Graphics/Editors and Converters
License:        GPLv2+
URL:            https://www.aseprite.org/
# Git repo: https://github.com/aseprite/aseprite
# Upstream zip archive repacked without unused third party libs
# rm -rf third_party/{cmark,curl,fmt,freetype2,giflib,harfbuzz,jpeg,libarchive,libpng,libwebp,pixman,pixman-cmake,tinyxml2,zlib}
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}.1
# From third_party/pixman/pixman/pixman-combine32.h
Source2:        pixman-combine32.h
Patch1:         aseprite-shared-fmt.patch
# Based on https://patch-diff.githubusercontent.com/raw/aseprite/aseprite/pull/2535.patch
Patch2:         aseprite-shared-libarchive.patch
# Based on https://patch-diff.githubusercontent.com/raw/aseprite/aseprite/pull/2523.patch
Patch3:         aseprite-shared-libwebp.patch
Patch4:         aseprite-fix-build-with-gcc15.patch

BuildRequires:  cmake
BuildRequires:  allegro4-devel
BuildRequires:  giflib-devel
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(tinyxml2)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libcmark)
BuildRequires:  pkgconfig(harfbuzz)

%description
Aseprite (aka ASE, Allegro Sprite Editor) is an open source program to
create animated sprites & pixel art. Sprites are little images that can
be used in your website or in a video game. You can draw characters with
movement, intros, textures, patterns, backgrounds, logos, color palettes,
isometric levels, etc.

%prep
%autosetup -p1

# Needed to build doc-lib
mkdir -p third_party/pixman/pixman
cp %{_sourcedir}/pixman-combine32.h third_party/pixman/pixman/

# Stable version
sed -i data/gui.xml src/config.h -e 's/-dev//'

%build
# The window can't be resized/maximize when linked against the system allegro 4
# We build against the embedded version for now - patching allegro could be investigated too
# allegro is still needed as a BR for libloadpng
%cmake -DENABLE_UPDATER=OFF \
       -DUSE_SHARED_CMARK=ON \
       -DUSE_SHARED_CURL=ON \
       -DUSE_SHARED_FMT=ON \
       -DUSE_SHARED_FREETYPE=ON \
       -DUSE_SHARED_GIFLIB=ON \
       -DUSE_SHARED_HARFBUZZ=ON \
       -DUSE_SHARED_LIBARCHIVE=ON \
       -DUSE_SHARED_JPEGLIB=ON \
       -DUSE_SHARED_LIBPNG=ON \
       -DUSE_SHARED_PIXMAN=ON \
       -DUSE_SHARED_TINYXML=ON \
       -DUSE_SHARED_WEBP=ON \
       -DUSE_SHARED_ZLIB=ON \
       -DENABLE_WEBP=ON
%cmake_build

%install
%cmake_install

rm -rf %{buildroot}%{_includedir}
find %{buildroot} -name '*.a' -delete
find %{buildroot} -name '*.pc' -delete

install -D -m644 %{_sourcedir}/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1

for size in 16 32 48 64 128 256; do
  install -D -m644 data/icons/ase${size}.png \
          %{buildroot}%{_iconsdir}/hicolor/${size}x${size}/apps/%{name}.png
done

install -d %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Name=Aseprite
GenericName=Sprite editor
Comment=Animated sprite editor & pixel art tool
Exec=%{name}
Icon=%{name}
Type=Application
Categories=Graphics;2DGraphics;RasterGraphics;
EOF

%files
%doc CONTRIBUTING.md README.md
%license EULA.txt
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man1/%{name}.1*


%changelog
* Wed May 07 2025 ns80 <ns80> 1.3.9.1-2.mga10
+ Revision: 2181800
- try to fix building with GCC 15

* Mon Oct 14 2024 daviddavid <daviddavid> 1.3.9.1-1.mga10
+ Revision: 2106868
- new version: 1.3.9.1
- use system fmt, libarchive and libwebp

* Mon Sep 30 2024 ns80 <ns80> 1.3.8.1-1.mga10
+ Revision: 2102092
- use more bundled libraries
- use some bundled libraries
- new version 1.3.8.1

* Thu Mar 31 2022 umeabot <umeabot> 1.1.7-8.mga9
+ Revision: 1836105
- Mageia 9 Mass Rebuild

* Wed Apr 15 2020 danf <danf> 1.1.7-7.mga8
+ Revision: 1567458
- Fix Comment= in .desktop file to stop referring to debug sources

* Fri Feb 14 2020 umeabot <umeabot> 1.1.7-6.mga8
+ Revision: 1519208
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sat Oct 06 2018 daviddavid <daviddavid> 1.1.7-5.mga7
+ Revision: 1318156
- fix embedded allegro app builds failing due to alcompat.h defining aliases for
  fadd / fdiv / fmull which conflict with system headers
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild
- Mageia 7 Mass Rebuild

* Sun Aug 06 2017 daviddavid <daviddavid> 1.1.7-3.mga7
+ Revision: 1137572
- rebuild for new libwebp 0.6.0

* Sun Mar 12 2017 akien <akien> 1.1.7-2.mga6
+ Revision: 1092238
- Rebuild against allegro4

* Sat Aug 13 2016 akien <akien> 1.1.7-1.mga6
+ Revision: 1046148
- Version 1.1.7
- Strip the erroneous -dev suffix in version string
- Version 1.1.6

* Tue May 10 2016 akien <akien> 1.1.5.3-1.mga6
+ Revision: 1012252
- Version 1.1.5.3

* Tue Apr 12 2016 akien <akien> 1.1.4-1.mga6
+ Revision: 1000892
- Version 1.1.4
- Build against system giflib

* Thu Jan 07 2016 neoclust <neoclust> 1.0.9-3.mga6
+ Revision: 920432
- dont_use_x86_assembly.patch:
    - Added. Fixes FTBFS with GCC 5. ( From Debian )

* Thu Sep 03 2015 cjw <cjw> 1.0.9-2.mga6
+ Revision: 872501
- rebuild with gcc 5

* Thu Mar 05 2015 akien <akien> 1.0.9-1.mga5
+ Revision: 817871
- Remove Debian-specific content in the manpage
- Package some doc
- imported package aseprite

